API Reference
#############

Regridding
----------

.. autosummary::
   :toctree: generated/

   ufs2arco.Layers2Pressure


Data Sources
------------

.. autosummary::
   :toctree: generated/

   ufs2arco.sources.Source
   ufs2arco.sources.AWSGEFSArchive
   ufs2arco.sources.AWSHRRRArchive
   ufs2arco.sources.GFSArchive

Data Targets
------------

.. autosummary::
   :toctree: generated/

   ufs2arco.targets.Target
   ufs2arco.targets.Anemoi


Utilities
---------

.. autosummary::
   :toctree: generated/

   ufs2arco.utils.expand_anemoi_dataset
   ufs2arco.utils.convert_anemoi_inference_dataset
